==> python-darkslide_5.1.0.orig.tar.gz: python-darkslide-5.1.0/examples/markdown/slides.md <==
# Title Slide

.footer: [default theme](.) | [abyss theme](abyss.html) | [void theme](void.html) | [white theme](white.html) | [github](https://github.com/ionelmc/python-darkslide)

---

# Paragraphs

.notes: notes

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris ultricies
tempus ultricies. Ut porta scelerisque viverra. Pellentesque aliquam metus
scelerisque dui ultricies, auctor dictum erat aliquet. Integer vehicula nunc
elit, vel iaculis lorem facilisis non.

.notes: more notes

Vivamus ante mauris, pellentesque et rhoncus ut, condimentum sed ipsum.
Nullam eu molestie sapien. Curabitur imperdiet, ligula id blandit sagittis,
libero quam consectetur felis, ac pharetra metus lectus vitae leo. Mauris
lacinia fermentum augue.

---

# Blockquotes

> Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris ultricies
> tempus ultricies. Ut porta scelerisque viverra. Pellentesque aliquam metus
> scelerisque dui ultricies, auctor dictum erat aliquet. Integer vehicula nunc
> elit, vel iaculis lorem facilisis non.

---

# Subheadings and Emphasis

## Italic

*Lorem ipsum dolor sit amet*

## Bold

**Lorem ipsum dolor sit amet**

---

# First heading: *lorem ipsum* dolor sit
## Second: *lorem ipsum* dolor sfi amet, consecte
### Third: *lorem ipsum* dolor sit amet, consectetur adipiscing

* 1
* 2
* 3
* 4
* 5
* 6
* 7

---

# Lists

## Unordered List

- Markdown
- ReStructured Text
- Textile

## Ordered List

1. Python
2. JavaScript
3. HTML5

---

# Second Title Slide

---

# Code

## Single Word

Hello `World`

## Python

    !python
    def multiply (x, y):
        return x * y

## JavaScript

    !javascript
    multiply: function (x, y) {
      return x * y;
    }

## HTML

    !html
    <!doctype html>
    <html>
      <head></head>
      <body></body>
    </html>

---

# Images

![Landscape](../_assets/landscape.jpg)

---

# View Presenter Notes

This slide has presenter notes. Press `p` to view them.

# Presenter Notes

Hello from presenter notes

---

# TOC and subsections

A presentation supports multiple section levels. Subsections can be used to organize contents.

The global TOC includes sections and subsections.

The max-toc-level parameter allows the user to limit the number of subsections included in the global TOC.

---

## Subsection A

This slide is a subsection of the section "Toc and subsections"

---

## Subsection B

This slide is a subsection of the section "Toc and subsections"

---

# Other features

View other features in the help sidebar by pressing `h`

==> python-darkslide_6.0.0.orig.tar.gz: python-darkslide-6.0.0/examples/markdown/slides.md <==
# Title Slide

.footer: Themes: [default](index.html) | [abyss](abyss.html) | [void](void.html) | [white](white.html) Themes 16x9: [default](default_wide16x9.html) | [abyss](abyss_wide16x9.html) | [void](void_wide16x9.html) | [white](white_wide16x9.html)    Project: [github](https://github.com/ionelmc/python-darkslide)

---

# Paragraphs

.notes: notes

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris ultricies
tempus ultricies. Ut porta scelerisque viverra. Pellentesque aliquam metus
scelerisque dui ultricies, auctor dictum erat aliquet. Integer vehicula nunc
elit, vel iaculis lorem facilisis non.

.notes: more notes

Vivamus ante mauris, pellentesque et rhoncus ut, condimentum sed ipsum.
Nullam eu molestie sapien. Curabitur imperdiet, ligula id blandit sagittis,
libero quam consectetur felis, ac pharetra metus lectus vitae leo. Mauris
lacinia fermentum augue.

---

# Blockquotes

> Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris ultricies
> tempus ultricies. Ut porta scelerisque viverra. Pellentesque aliquam metus
> scelerisque dui ultricies, auctor dictum erat aliquet. Integer vehicula nunc
> elit, vel iaculis lorem facilisis non.

---

# Subheadings and Emphasis

## Italic

*Lorem ipsum dolor sit amet*

## Bold

**Lorem ipsum dolor sit amet**

---

# First heading: *lorem ipsum* dolor sit
## Second: *lorem ipsum* dolor sfi amet, consecte
### Third: *lorem ipsum* dolor sit amet, consectetur adipiscing

* 1
* 2
* 3
* 4
* 5
* 6
* 7

---

# Lists

## Unordered List

- Markdown
- ReStructured Text
- Textile

## Ordered List

1. Python
2. JavaScript
3. HTML5

---

# Second Title Slide

---

# Code

## Single Word

Hello `World`

## Python

    !python
    def multiply (x, y):
        return x * y

## JavaScript

    !javascript
    multiply: function (x, y) {
      return x * y;
    }

## HTML

    !html
    <!doctype html>
    <html>
      <head></head>
      <body></body>
    </html>

---

# Images

![Landscape](../_assets/landscape.jpg)

---

# View Presenter Notes

This slide has presenter notes. Press `p` to view them.

# Presenter Notes

Hello from presenter notes

---

# TOC and subsections

A presentation supports multiple section levels. Subsections can be used to organize contents.

The global TOC includes sections and subsections.

The max-toc-level parameter allows the user to limit the number of subsections included in the global TOC.

---

## Subsection A

This slide is a subsection of the section "Toc and subsections"

---

## Subsection B

This slide is a subsection of the section "Toc and subsections"

---

# Other features

View other features in the help sidebar by pressing `h`
